@@ -17,15 +17,15 @@ END {
 
 =head1 NAME
 
-IO::Iron::IronMQ::Message
+IO::Iron::IronMQ::Message - IronMQ (Message Queue) Client (Message).
 
 =head1 VERSION
 
-Version 0.01_03
+Version 0.01_04
 
 =cut
 
-our $VERSION = '0.01_03';
+our $VERSION = '0.01_04';
 
 
 =head1 SYNOPSIS
@@ -37,7 +37,6 @@ Please see IO::Iron::IronMQ::Client for usage.
 =cut
 
 use Log::Any  qw($log);
-use utf8;
 use Hash::Util qw{lock_keys unlock_keys};
 use Carp::Assert::More;
 use English '-no_match_vars';
